@@ -7,6 +7,10 @@
 #include <QStandardPaths>
 #include <QLoggingCategory>
 
+constexpr const char* kLogExportService = "org.deepin.logviewer.service.opsLogExport";
+constexpr const char* kLogExportPath = "/org/deepin/logviewer/service/opsLogExport";
+constexpr const char* kLogExportInterface = "org.deepin.logviewer.service.opsLogExport";
+
 Q_DECLARE_LOGGING_CATEGORY(logApp)
 
 DLDBusHandler *DLDBusHandler::m_statichandeler = nullptr;
@@ -172,6 +176,22 @@ QStringList DLDBusHandler::getOtherFileInfo(const QString &flag, bool unzip)
     return filePathList;
 }
 
+bool DLDBusHandler::exportOpsLog(const QString &outDir, const QString &userHomeDir)
+{
+    QDBusMessage message = QDBusMessage::createMethodCall(kLogExportService,
+                                                          kLogExportPath,
+                                                          kLogExportInterface,
+                                                          "ExportOpsLog");
+    message << outDir << userHomeDir;
+
+    QDBusMessage reply = QDBusConnection::systemBus().call(message, QDBus::Block, 1200000);
+    if (reply.type() == QDBusMessage::ErrorMessage) {
+        qCritical(logApp) << "call dbus interface 'exportHwOpsLog' failed. error info:" << reply.errorMessage();
+        return false;
+    }
+
+    return reply.arguments().first().toBool();
+}
 
 bool DLDBusHandler::exportLog(const QString &outDir, const QString &in, bool isFile)
 {
