@@ -21,6 +21,7 @@ public:
     int exitCode();
     void quit();
     bool exportLog(const QString &outDir, const QString &in, bool isFile);
+    bool exportOpsLog(const QString &outDir, const QString &userHomeDir);
     bool isFileExist(const QString &filePath);
     quint64 getFileSize(const QString &filePath);
     qint64 getLineCount(const QString &filePath);
@@ -32,10 +33,16 @@ public:
 private:
     explicit DLDBusHandler(QObject *parent = nullptr);
 
+private:
+    QString createFilePathCacheFile(const QString& logFilePath);
+    void releaseFilePathCacheFile(const QString &cacheFilePath);
+
 private:
     static DLDBusHandler *m_statichandeler;
     DeepinLogviewerInterface *m_dbus;
     QStringList filePath;
+
+    QTemporaryDir m_tempDir;
 };
 
 #endif // DLDBUSHANDLER_H
