@@ -15,6 +15,8 @@
 #include <QJsonObject>
 #include <QDateTime>
 #include <QSet>
+#include <QStandardPaths>
+#include <QTemporaryDir>
 
 Q_DECLARE_LOGGING_CATEGORY(logApp)
 
@@ -52,10 +54,61 @@ bool LogAllExportThread::addFileToZip(const QString &filePath, const QString &zi
 {
     if (m_cancel.load() || !m_zipFile) return false;
 
+    // Try direct file access first
     QFile file(filePath);
     if (!file.open(QIODevice::ReadOnly)) {
-        qCWarning(logApp) << "Failed to open file for zipping:" << filePath;
-        return false;
+        qCDebug(logApp) << "Direct file access failed, trying DBus export for:" << filePath;
+
+        // For permission-restricted files like auth.log, use DBus exportLog interface
+        if (DLDBusHandler::instance(nullptr)->exportLog(QFileInfo(m_outfile).path(), filePath, true)) {
+            // Read the exported content and add to zip
+            QFile exportedFile(QFileInfo(m_outfile).path() + "/" + QFileInfo(filePath).fileName());
+            if (exportedFile.open(QIODevice::ReadOnly)) {
+                QByteArray content = exportedFile.readAll();
+                exportedFile.close();
+                exportedFile.remove(); // Clean up exported file
+
+                // Create zip entry directly from DBus content
+                zip_fileinfo zfi = {};
+                QFileInfo fileInfo(filePath);
+                if (fileInfo.exists()) {
+                    QDateTime lastModified = fileInfo.lastModified();
+                    zfi.tmz_date = dateTimeToTmZip(lastModified);
+                    zfi.dosDate = 0;
+                }
+
+                zipOpenNewFileInZip64(m_zipFile, zipEntryName.toUtf8().constData(), &zfi, nullptr, 0, nullptr, 0, nullptr, Z_DEFLATED, ZIP_COMPRESSION_LEVEL, 1);
+
+                const char* data = content.constData();
+                qint64 size = content.size();
+                qint64 offset = 0;
+                char buf[ZIP_BUFFER_SIZE];
+
+                while (size > 0) {
+                    qint64 bytesToWrite = qMin(static_cast<qint64>(ZIP_BUFFER_SIZE), size);
+                    memcpy(buf, data + offset, bytesToWrite);
+
+                    if (zipWriteInFileInZip(m_zipFile, buf, bytesToWrite) != ZIP_OK) {
+                        qCCritical(logApp) << "Failed to write DBus content to zip stream for file:" << filePath;
+                        zipCloseFileInZip(m_zipFile);
+                        return false;
+                    }
+
+                    offset += bytesToWrite;
+                    size -= bytesToWrite;
+                }
+
+                zipCloseFileInZip(m_zipFile);
+                qCDebug(logApp) << "Successfully added file to zip via DBus:" << filePath;
+                return true;
+            } else {
+                qCWarning(logApp) << "Failed to read exported file from DBus:" << filePath;
+                return false;
+            }
+        } else {
+            qCWarning(logApp) << "Failed to export file via DBus:" << filePath;
+            return false;
+        }
     }
 
     // Get file modification time and set it in zip_fileinfo
@@ -292,6 +345,10 @@ void LogAllExportThread::run()
         } else if (it.contains(AUDIT_TREE_DATA, Qt::CaseInsensitive)) {
             data.logCategory = "audit";
             data.files.append(DLDBusHandler::instance(nullptr)->getFileInfo("audit", false));
+        } else if (it.contains(AUTH_TREE_DATA, Qt::CaseInsensitive)) {
+            data.logCategory = "auth";
+            QStringList authLogFiles = LogApplicationHelper::instance()->getAuthLogList();
+            data.files.append(authLogFiles);
         }
 
         data.files.removeDuplicates();
@@ -308,6 +365,9 @@ void LogAllExportThread::run()
         return;
     }
 
+    // Add task for ops log
+    totalTasks += 10;
+
     emit updateTolProcess(totalTasks);
     int completedTasks = 0;
 
@@ -321,7 +381,7 @@ void LogAllExportThread::run()
             // Optimize: extract filename without constructing QFileInfo
             int lastSlash = file.lastIndexOf('/');
             QString fileName = (lastSlash >= 0) ? file.mid(lastSlash + 1) : file;
-            QString entryName = data.logCategory + '/' + fileName;
+            QString entryName = "log/" + data.logCategory + '/' + fileName;
             ensureDirectoriesExist(entryName);
             if (!addFileToZip(file, entryName)) {
                  qCWarning(logApp) << "Failed to add file to zip:" << file;
@@ -340,7 +400,7 @@ void LogAllExportThread::run()
                 // Optimize: extract filename without constructing QFileInfo
                 int lastSlash = path.lastIndexOf('/');
                 QString fileName = (lastSlash >= 0) ? path.mid(lastSlash + 1) : path;
-                QString entryName = data.logCategory + '/' + fileMapIt.key() + '/' + fileName;
+                QString entryName = "log/" + data.logCategory + '/' + fileMapIt.key() + '/' + fileName;
                 ensureDirectoriesExist(entryName);
                 if (!addFileToZip(path, entryName)) {
                     qCWarning(logApp) << "Failed to add file to zip:" << path;
@@ -353,7 +413,7 @@ void LogAllExportThread::run()
         // Commands in category root
         for (const auto &command : data.commands) {
             if (m_cancel.load()) break;
-            QString entryName = data.logCategory + '/' + command + ".log";
+            QString entryName = "log/" + data.logCategory + '/' + command + ".log";
             ensureDirectoriesExist(entryName);
             
             if (command == "journalctl_system") {
@@ -388,13 +448,13 @@ void LogAllExportThread::run()
                     QString filter = obj["filter"].toString();
                     
                     if (logType == "journal" && !filter.isEmpty()) {
-                        QString entryName = data.logCategory + '/' + cmdMapIt.key() + '/' + filter + ".log";
+                        QString entryName = "log/" + data.logCategory + '/' + cmdMapIt.key() + '/' + filter + ".log";
                         ensureDirectoriesExist(entryName);
                         addProcessOutputToZip("journalctl", QStringList() << "-u" << filter, entryName);
                     }
                 } else {
                     // Fallback for malformed JSON
-                    QString entryName = data.logCategory + '/' + cmdMapIt.key() + "/journal.log";
+                    QString entryName = "log/" + data.logCategory + '/' + cmdMapIt.key() + "/journal.log";
                     ensureDirectoriesExist(entryName);
                     addProcessOutputToZip("journalctl", QStringList(), entryName);
                 }
@@ -403,6 +463,88 @@ void LogAllExportThread::run()
         }
     }
 
+    // --- Export additional ops logs ---
+    if (!m_cancel.load()) {
+        // Create temporary directory for ops logs
+        QString userHomePath = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+        QString opsLogPath = QDir::tempPath() + "/deepin-log-viewer-ops-logs-" + QString::number(QDateTime::currentMSecsSinceEpoch());
+
+        if (QDir().mkpath(opsLogPath)) {
+            DLDBusHandler::instance(this)->exportOpsLog(opsLogPath, userHomePath);
+            completedTasks += 5;
+            emit updatecurrentProcess(completedTasks);
+            Utils::exportSomeOpsLogs(opsLogPath, userHomePath);
+            completedTasks += 2;
+            emit updatecurrentProcess(completedTasks);
+
+            // Add ops logs to zip file with directory structure preserved
+            QDir opsDir(opsLogPath);
+            if (opsDir.exists()) {
+                // Recursive function to add directory structure to zip
+                std::function<void(const QDir&, const QString&)> addDirToZip = [&](const QDir& currentDir, const QString& basePath) {
+                    if (m_cancel.load()) return;
+
+                    // First, add all files in current directory
+                    QStringList files = currentDir.entryList(QDir::Files | QDir::NoDotAndDotDot);
+                    for (const QString &file : files) {
+                        if (m_cancel.load()) break;
+
+                        QString filePath = currentDir.filePath(file);
+                        QString entryName = "log-ops/" + basePath + file;
+                        ensureDirectoriesExist(entryName);
+
+                        if (!addFileToZip(filePath, entryName)) {
+                            qCWarning(logApp) << "Failed to add ops log file to zip:" << entryName;
+                        }
+                    }
+
+                    // Create directory entry for current directory if it's empty or has subdirectories
+                    if (files.isEmpty()) {
+                        QString dirEntryName = "log-ops/" + basePath;
+                        if (!dirEntryName.endsWith('/')) {
+                            dirEntryName += '/';
+                        }
+
+                        // Create empty directory entry
+                        zip_fileinfo zfi = {};
+                        QDateTime currentTime = QDateTime::currentDateTime();
+                        zfi.tmz_date = dateTimeToTmZip(currentTime);
+                        zfi.dosDate = 0;
+
+                        if (zipOpenNewFileInZip64(m_zipFile, dirEntryName.toUtf8().constData(), &zfi, nullptr, 0, nullptr, 0, nullptr, Z_DEFLATED, ZIP_COMPRESSION_LEVEL, 1) == ZIP_OK) {
+                            zipCloseFileInZip(m_zipFile);
+                        }
+                    }
+
+                    // Then, recursively process subdirectories
+                    QStringList subDirs = currentDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+                    for (const QString &subDir : subDirs) {
+                        if (m_cancel.load()) break;
+
+                        QDir subDirectory = currentDir;
+                        if (subDirectory.cd(subDir)) {
+                            QString subPath = basePath + subDir + "/";
+                            addDirToZip(subDirectory, subPath);
+                        }
+                    }
+                };
+
+                // Start recursive addition from the ops directory
+                addDirToZip(opsDir, "");
+            }
+            completedTasks += 2;
+            emit updatecurrentProcess(completedTasks);
+            // Clean up temporary directory
+            if (!Utils::deleteDir(opsLogPath)) {
+                qCWarning(logApp) << "Failed to remove temporary ops log directory:" << opsLogPath;
+            }
+            completedTasks += 1;
+            emit updatecurrentProcess(completedTasks);
+        } else {
+            qCCritical(logApp) << "Failed to create temporary ops log directory:" << opsLogPath;
+        }
+    }
+
     zipClose(m_zipFile, "Exported by Deepin Log Viewer");
     m_zipFile = nullptr;
 
